@@ -1,7 +1,8 @@
-from typing import Dict
+from __future__ import annotations
 
 # now: 448~2785
-HEIGHT_GAP: Dict[int, int] = {
+# with invalid height, horizontal lines appears
+HEIGHT_GAP: dict[int, int] = {
     448: 0,
     472: 24,
     480: 0,
@@ -23,7 +24,12 @@ HEIGHT_GAP: Dict[int, int] = {
     1149: 26,
     1163: 8,
     1200: 16,
+    1236: 18,
+    1300: 17,
+    1378: 0,
     1400: 22,
+    1536: 0,
+    1593: 22,
     1600: 0,
     1811: 16,
     1826: 0,
@@ -36,7 +42,8 @@ HEIGHT_GAP: Dict[int, int] = {
 
 
 # now: 332~1480
-WIDTH_GAP: Dict[int, int] = {
+# with invalid width, vartical lines appears
+WIDTH_GAP: dict[int, int] = {
     332: 10,
     426: 8,
     438: 20,
@@ -67,13 +74,18 @@ WIDTH_GAP: Dict[int, int] = {
     844: 10,
     847: 12,
     848: 14,
+    850: 16,
+    862: 30,
+    921: 22,
     958: 27,
+    960: 0,
     980: 18,
     1037: 10,
     1042: 16,
     1061: 4,
     1070: 12,
     1073: 14,
+    1080: 22,
     1084: 26,
     1085: 26,
     1091: 0,
@@ -83,6 +95,7 @@ WIDTH_GAP: Dict[int, int] = {
     1103: 12,
     1108: 18,
     1109: 20,
+    1100: 10,
     1114: 23,
     1115: 24,
     1120: 0,
@@ -94,6 +107,7 @@ WIDTH_GAP: Dict[int, int] = {
     1128: 6,
     1133: 10,
     1326: 12,
+    1350: 4,
     1353: 8,
     1394: 16,
     1408: 0,
@@ -102,6 +116,7 @@ WIDTH_GAP: Dict[int, int] = {
     1441: 0,
     1443: 0,
     1444: 2,
+    1445: 2,
     1453: 10,
     1480: 6,
 }
